// A bar graph visualization of canceled flights from a
// flight dataset covering 1997-2004.  A simple demonstration
// of looking for meaningful patterns visually in a big pile
// of data.  Guess which month stands out.

Table tab;
float highest_canceled;
float bar_width;
int rows;

void setup()
{
  size( 600, 400 );

  // Load in the CSV file (go look at it!)
  tab = loadTable( "ontime.csv", "header" );

  highest_canceled = 0.0;
  rows = tab.getRowCount();
  bar_width = width / float( rows );

  // In a first pass, need to precompute the month
  // with the highest percentage of cancelations as
  // a fraction of all flights.
  for ( int idx = 0; idx < rows; ++idx ) {
    int total = tab.getInt( idx, "Total" );
    int canceled = tab.getInt( idx, "Canceled" );
    float pct = float(canceled)/float(total);
    if ( pct > highest_canceled ) {
      highest_canceled = pct;
    }
  }
}

void draw()
{
  background( 255 );

  fill( 128 );
  
  int bar = -1;

  // Now we can go ahead and draw a graph.
  for ( int idx = 0; idx < rows; ++idx ) {
    int total = tab.getInt( idx, "Total" );
    int canceled = tab.getInt( idx, "Canceled" );
    float pct = float(canceled)/float(total);

    float t = pct / highest_canceled;
    float bar_height = lerp( 0, height, t );

    float x = idx * bar_width;
    rect( x, height - bar_height, bar_width, bar_height );
    
    // Track the X position of the mouse to decide which
    // bar to report on.
    if( (x <= mouseX) && (mouseX <= x + bar_width) ) {
      bar = idx;
    }
  }
  
  if( bar != -1 ) {
    stroke( 0 );
    fill( 0 );
    text( tab.getString( bar, "Month" ) + " " + tab.getInt( bar, "Year" ), 5, 20 );
    text( "Total flights: " + tab.getInt( bar, "Total" ), 5, 35 );
    text( "Canceled flights: " + tab.getInt( bar, "Canceled" ), 5, 50 );
  }
}