// Process a file that's sort of like a table but 
// isn't in CSV format.  In this case the table has
// a lot of extraneous ASCII art.  But with a bit
// of ingenuity we can figure out how to build a 
// table from it.

void setup()
{
  // Create a table and declare the names of the two
  // columns we're planning to have in it.
  Table table = new Table();
  table.addColumn( "Name" );
  table.addColumn( "Municipality" );

  // Load in the text file.
  String[] lines = loadStrings( "ReservedStreetnames.txt" );
  // Walk over every line in the file.
  for ( int idx = 0; idx < lines.length; ++idx ) {
    if ( lines[idx].startsWith( "-" ) ) {
      // Line starts with -, just skip it.
      continue;
    } else {
      // Extract the text.  Be clever, and use the vertical
      // pipe character "|" as a delimiter.
      String[] boxes = splitTokens( lines[idx], "|" );
      // Use the trim() function to remove extra 
      // whitespace around every street name and 
      // municipality.  Note that the function trim()
      // can be applied to an *array* of Strings, in 
      // which case it trims each String in the array.
      boxes = trim( boxes );

      // OK, we've got the information that will make up
      // a new table row.  But note that the first "row"
      // in the text file is a header for each column.
      // Let's catch that and toss it out.  Otherwise
      // store the information in the table.
      if ( !boxes[0].equals( "FullStreetName" ) ) {
        // Create a new table row and populate it with
        // information.
        TableRow row = table.addRow();
        row.setString( "Name", boxes[0] );
        row.setString( "Municipality", boxes[1] );
      }
    }
  }

  // We've filled up the table.  What do you want to do
  // with it?
  println( "Found " + table.getRowCount() + " records" );
}