// Visualize salary data as a histogram.  Find the range of
// all salaries in the CSV file, and then divide that range 
// up into bins and draw each bin as a bar within the sketh
// window.

void setup()
{
  size( 800, 400 );
  background( 255 );
  fill( 128 );
  stroke( 0 );

  // Read the CSV file.
  Table table = loadTable( "pssd_processed.csv", "header" );

  // Find the maximum salary.  First create a variable to
  // keep track of the maximum salary, and set it to zero.
  float maxsal = 0;
  for ( int idx = 0; idx < table.getRowCount (); ++idx ) {
    // Now, for each row of the table, check whether the
    // salary in that row beats the best salary we've seen
    // so far.  If so, remember that.
    float sal = table.getFloat( idx, "Salary" );
    maxsal = max( sal, maxsal );
  }
  // round maxsal up to the nearest 20K.
  maxsal = maxsal - (maxsal % 10000) + 10000;

  // Divide up the space of all salaries into 20K bins,
  // figure out how many bins are needed based on the max
  // salary.
  int bins = int( (maxsal-100000)/20000 ) + 1;
  // Create an array of bins.
  int[] counts = new int[ bins ];

  // Walk over all salaries, sorting salaries into bins.
  // Every time you see a salary that belongs in bin "bidx",
  // increment the count of salaries stored in that bin
  // (which will later translate into the height of the bar
  // to draw).
  for ( int idx = 0; idx < table.getRowCount (); ++idx ) {
    float sal = table.getFloat( idx, "Salary" );
    int bidx = int( (sal - 100000) / 20000 );
    counts[bidx]++;
  }

  // Draw the histogram.
  // Figure out the size of the largest bin, and use that
  // as a scaling factor for all the bars.
  int maxcount = max( counts );
  // Figure out the width of a bar.
  float w = (width - 100) / float( bins );

  for ( int idx = 0; idx < counts.length; ++idx ) {
    if ( counts[idx] > 0 ) {
      float h = map( counts[idx], 0, maxcount, 0, height - 100 );
      rect( 50 + w*idx, height-50-h, w, h );
    }
  }
}