// A quick aggregate data visualization of all disclosed
// university employee salaries in Ontario.  Separate the
// data into four categories: Assistant Professors, Associate
// Professors, Full Professors, and Others.  These will be
// rendered from bottom to top in the sketch.

float getMaxSalary( Table table )
{
  // Compute the maximum salary in the table.
  float maxsal = 0;
  for ( int idx = 0; idx < table.getRowCount(); ++idx ) {
    float sal = table.getFloat( idx, "Salary" );
    maxsal = max( sal, maxsal );
  }
  // Scale it so that we know nothing will sit right at the right
  // edge of the sketch.
  return 1.05 * maxsal;
}

void setup()
{
  size( 800, 400 );
  background( 255 );
  noStroke();

  // Load in the CSV.
  Table table = loadTable( "pssd_processed.csv", "header" );

  float maxsal = getMaxSalary( table );

  // Walk over every row in the table.
  for ( int idx = 0; idx < table.getRowCount(); ++idx ) {
    // Get the position string, and check whether it's likely to
    // belong to one of the categories we care about.  If so,
    // put it in that category.  Otherwise, may as well stick it
    // into "other".
    String pos = table.getString( idx, "Position" ).toLowerCase();
    float sal = table.getFloat( idx, "Salary" );

    // Find the X position where we're going to draw a marker
    // for this employee.
    float x = map( sal, 100000, maxsal, 0, width );
    float y = 0;

    if ( pos.contains( "assistant professor" ) ) {
      // Probably an "Assistant Professor".
      fill( #00ff00, 50 );
      y = 300;
    } else if ( pos.contains( "associate professor" ) ) {
      // Probably an "Associate Professor".
      fill( #0000ff, 50 );
      y = 200;
    } else if ( match( pos, "professor" ) != null ) {
      // Professor, but neither assistant nor associate.
      // Probably a a "Full Professor" (the highest rank
      // for profs in North America).
      fill( #ff0000, 50 );
      y = 100;
    } else {
      fill( #404040, 50 );
    }
    
    //ellipse( x, random(300, 400), 6, 6 );
    rect( x - 2, y, 4, 100 );
  }

  save( "viz.png" );
}